﻿' -----------------------------------------------------------------------------------------
'
' Kurve91.vb                                                        Ulrich Müller  11.06.06
'                                                                   PCS1700 VB 2005 Express
' Modell Kurvenschreiber aus Kasten 30 490 Profi Computing von 1991
' ACHTUNG : Um RobMotoren nutzen zu können wurde die Interfacebelegung leicht modifiziert
'           Siehe Const Interfacebelegung
' Basis ist die Assembly FishFace2005.DLL
'
' -----------------------------------------------------------------------------------------

Option Explicit On
Option Strict Off
Imports FishFace40

Public Class Kurve91

  ' --- Interfacebelegung ---
  Const mSchreiber = 1             ' --- zum Endtaster : Dir.Links
  Const iEndSchreiber = 1
  Const iImpulsSchreiber = 2
  Const maxImpulsSchreiber = 280
  Const mStift = 2
  Const iEndStift = 3
  Const mPapier = 3                ' --- vorwärts : Dir.Rechts
  Const iImpulsPapier = 6
  Const aPhoto = 1
  Const minPhoto = 0
  Const maxPhoto = 1023
  Const messBereich = maxPhoto - minPhoto
  Const messFaktor = messBereich \ maxImpulsSchreiber

  ' --- Instanz der Klasse FishRobot ---
  Dim MotList(,) As Integer = {{mSchreiber, maxImpulsSchreiber}}
  Dim WithEvents ft As New FishRobot(MotList)

  ' --- Zentrale Steuerungsroutine ---------
  Private Sub Action()
    InitKurve()
    Do
      AnalogWert()
      ZeilenVorschub()
      ft.Pause(5000)              ' --- Messung in 5 Sekundenintervallen ( + Fahrzeiten )
    Loop Until ft.Finish()
    ft.NotHalt = False            ' --- um NotHalt-Bedingung von Abbruch wieder aufzuheben
    MoveStift(True)               ' --- Parkposition
    ft.MoveHome()
  End Sub

  Private Sub InitKurve()
    MoveStift(True)                   ' --- Stift auf
    ft.MoveHome()                     ' --- Schreiber Home
    MoveStift(False)                  ' --- Stift ab
  End Sub

  Private Sub AnalogWert()
    Dim aWert As Integer = ft.GetAnalog(aPhoto)
    Dim zPos As Integer = (aWert - minPhoto) \ messFaktor
    ft.MoveTo(zPos)
    lblAnalog.Text = aWert
  End Sub

  Private Sub ZeilenVorschub()
    ft.SetMotor(mPapier, Dir.Rechts)
    ft.WaitForChange(iImpulsPapier, 1)
    ft.SetMotor(mPapier, Dir.Aus)
  End Sub

  Private Sub MoveStift(ByVal Auf As Boolean)
    If Auf Then
      ft.SetMotor(mStift, Dir.Links)    ' --- Stift heben
      ft.WaitForInput(iEndStift)
      ft.SetMotor(mStift, Dir.Aus)
    Else
      ft.SetMotor(mStift, Dir.Links)    ' --- Stift Senken
      ft.WaitForInput(iEndStift, False)
      ft.SetMotor(mStift, Dir.Aus)
    End If
  End Sub


#Region "--- ProgramControl ---"
  Private Sub cmdAction_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) _
  Handles cmdAction.Click
    ' --- Open erste ROBO Interface an USB oder Intelligent Interface an COM ---
    '     während des Ablaufs von Action gesperrt
    Try
      If cboPortName.SelectedIndex = 0 Then
        ft.OpenInterface(IFTypen.ftROBO_first_USB, 0)
      Else
        ft.OpenInterface(IFTypen.ftIntelligent_IF, cboPortName.SelectedIndex, 5)
      End If
      cmdAction.Enabled = False
      cmdEnde.Text = "&HALT"
      lblStatus.Text = "--- Bei der Arbeit ---"

      Action()          ' --- Nutz-Routine für die Anwendung

      ft.ClearMotors()
    Catch ex As FishFaceException
      MsgBox(ex.Message)
    Finally
      ft.CloseInterface()
      cmdAction.Enabled = True
      cmdEnde.Text = "&ENDE"
      lblStatus.Text = "--- Auf ein Neues ---"
      cmdEnde.Focus()
    End Try

  End Sub

  Private Sub cmdEnde_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdEnde.Click
    ' --- Programmende nur, wenn Action nicht läuft ---
    If cmdEnde.Text = "&HALT" Then ft.NotHalt = True Else Me.Close()
  End Sub

  Private Sub ManBeispiele_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
    ' --- Default erstes ROBO Interface an USB ---
    cboPortName.SelectedIndex = 0
  End Sub

  Private Sub ManBeispiele_FormClosing(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles MyBase.FormClosing
    ' --- Wenn Action läuft, wird ein Programmabbruch über (x) unterbunden ---
    If cmdEnde.Text = "&HALT" Then e.Cancel = True
  End Sub

#End Region

  Private Sub ft_PositionChange(ByVal sender As Object, ByVal ActPositions() As Integer) Handles ft.PositionChange
    lblPosition.Text = ActPositions(0)
  End Sub
End Class
